@@ -4,7 +4,7 @@
 #
 # For copyright and disclaimer see below.
 #
-# $Id: Instance.pm,v 1.3 2009-08-27 18:21:31 ubuntu Exp $
+# $Id: Instance.pm,v 1.6 2010-03-23 16:30:16 ubuntu Exp $
 #-----------------------------------------------------------------
 package SADI::Service::Instance;
 
@@ -14,7 +14,7 @@ use strict;
 
 # add versioning to this module
 use vars qw /$VERSION/;
-$VERSION = sprintf "%d.%02d", q$Revision: 1.3 $ =~ /: (\d+)\.(\d+)/;
+$VERSION = sprintf "%d.%02d", q$Revision: 1.6 $ =~ /: (\d+)\.(\d+)/;
 
 =head1 NAME
 
@@ -26,7 +26,7 @@ SADI::Service::Instance - A module that describes a SADI web service.
 
  # create a new blank SADI service instance object
  my $data = SADI::Service::Instance->new ();
- 
+
  # create a new primed SADI service instance object
  $data = SADI::Service::Instance->new (
      ServiceName => "helloworld",
@@ -42,7 +42,7 @@ SADI::Service::Instance - A module that describes a SADI web service.
      URL => "http://helloworld.com/cgi-bin/helloworld.pl",
      SignatureURL =>"http://foo.bar/myServiceDescription",
  );
- 
+
  # get the service name
  my $name = $data->ServiceName;
  # set the service name
@@ -99,7 +99,7 @@ SADI::Service::Instance - A module that describes a SADI web service.
  $data->SignatureURL($sig);
 
 =head1 DESCRIPTION
-	
+
 An object representing a SADI service signature.
 
 =head1 AUTHORS
@@ -230,11 +230,16 @@ A url to the SADI service signature.
 
 				# set the signature url to be the URL address unless defined
 				$i->SignatureURL( $i->URL ) unless $i->SignatureURL;
+				# set the service uri to be the URL address unless defined
+                $i->ServiceURI( $i->URL ) unless $i->ServiceURI;
+                # set the unique id to be the URL address unless defined
+                $i->UniqueIdentifier( $i->URL ) unless $i->UniqueIdentifier;
 			  }
 		},
 		Authoritative => { type => SADI::Base->BOOLEAN },
 		Format        => { type => SADI::Base->STRING },
 		SignatureURL  => { type => SADI::Base->STRING },
+		UnitTest     => { type => 'SADI::Service::UnitTest', is_array => 1 },
 	);
 
 	sub _accessible {
